@@ -204,7 +204,7 @@ class GMOauth():
         if Wnck.Screen.get_default():
             return "urn:ietf:wg:oauth:2.0:oob"
         else:
-            return "http://127.0.0.1:%d/" % oauthport
+            return "http://localhost:%d/" % oauthport
 
 
     def get_code(self, login_hint):
@@ -255,7 +255,7 @@ class GMOauth():
                     s.end_headers()
                     s.wfile.write("<html><head><title>Title</title></head>".encode())
 
-            httpd = HTTPServer(('127.0.0.1', oauthport), RequestHandler)
+            httpd = HTTPServer(('localhost', oauthport), RequestHandler)
             httpd.socket.settimeout(120)
             httpd.handle_request()
             return RequestHandler.code
@@ -572,9 +572,6 @@ class GMailURL():
         if address:
             qsdict['to'] = [address]
 
-        if 'attachment' in qsdict:
-            qsdict['attach'] = qsdict['attachment']
-
         outdict = {}
         for (key, value) in qsdict.items():
             for i in range(0, len(value)):
@@ -585,12 +582,15 @@ class GMailURL():
 
             outdict[key.lower()] = value
 
-        if 'su' in qsdict:
+        if 'su' in outdict:
             outdict["subject"] = outdict["su"]
 
-        if "body" not in qsdict:
+        if "body" not in outdict:
             outdict["body"] = " "
 
+        if 'attachment' in outdict:
+            outdict['attach'] = outdict['attachment']
+
         return(outdict)
 
     def simple_gmail_url(self):
